Learn R Programming

optbdmaeAT (version 1.0.1)

mmenubd.mae: Creates the main menu tcltk window

Description

Alternative to directly using the function optbdmaeAT on the R console, the function mmenubd.mae creates the main menu tcltk window with the list of four optimality criteria (A, MV, D and E) for search of optimal or near-optimal block designs for two-colour cDNA microarray experiments.

Usage

mmenubd.mae()

Arguments

Details

The main menu window created using the function mmenubd.mae contains the list of four optimality criteria (the A-, MV -, D- and E) for block designs that allows user to choose an optimality criterion of interest. The function will then call for a function fixpar.mae for further option regarding the setup of parametric combinations and output, see fixpar.mae documentation.

See Also

optbdmaeAT, fixparbd.mae, tcltk, TkWidgets